@@ -160,13 +160,14 @@ class QualityProcessTemplate(Object):
 
         - description       - The description of the new record
         - owner             - a User object representing the owner of the new record. Defaults to the authenticated User if not specified.
-        - number_format     - a NumberFormat object representing the numbering sequence to use. Defaults to the Template's assigned default sequence if not specified.
+        - number_format     - a NumberFormat object representing the numbering sequence to use. Defaults to the Template's assigned default sequence (if any) if not specified.
+        - prefix            - a string to specify which numbering prefix to use. Required if the number format has more than one prefix option.
 
         Returns: QualityProcess object
         """
 
         if not self.active:
-            raise RuntimeError("Cannot create new instance of inactive Quality Process Template.")
+            raise RuntimeError(f"Cannot create new instance of inactive Quality Process Template `{self.name}`.")
 
         number_format = number_format or self.default_number_format
 
